@@ -131,6 +131,7 @@
 #include <sys/time.h>
 #include <sys/resource.h>
 #include <regex.h>
+#include <glib.h>
 
 #include "atop.h"
 #include "acctproc.h"
@@ -142,8 +143,9 @@
 #include "parseable.h"
 #include "json.h"
 #include "gpucom.h"
+#include "netatop.h"
 
-#define	allflags  "ab:cde:fghijklmnopqrstuvwxyz1ABCDEFGHIJ:KL:MNOP:QRSTUVWXYZ"
+#define	allflags  "ab:cde:fghijklmnopqrstuvwxyz:1ABCDEFGHIJ:KL:MNOP:QRSTUVWXYZ"
 #define	MAXFL		64      /* maximum number of command-line flags  */
 
 /*
@@ -172,6 +174,11 @@ char      	rmspaces   = 0;  /* boolean: remove spaces from command  */
 
 char            displaymode = 'T';      /* 'T' = text, 'D' = draw        */
 char            barmono     = 0; /* boolean: bar without categories?     */
+		                 /* name in case of parseable output     */
+
+char		prependenv = 0;  /* boolean: prepend selected            */
+				 /* environment variables to cmdline     */
+regex_t		envregex;
 
 unsigned short	hertz;
 unsigned int	pidwidth;
@@ -181,6 +188,8 @@ int 		osrel;
 int 		osvers;
 int 		ossub;
 
+extern GHashTable *ghash_net;
+
 int		supportflags;	/* supported features             	*/
 char		**argvp;
 
@@ -419,7 +428,24 @@ main(int argc, char *argv[])
 				break;
 
                            case MCALCPSS:	/* calculate PSS per sample ? */
-				calcpss = 1;
+				if (rawreadflag)
+				{
+					fprintf(stderr,
+					        "PSIZE gathering depends on rawfile\n");
+					sleep(3);
+					break;
+				}
+
+                                calcpss    = 1;
+
+				if (!rootprivs())
+				{
+					fprintf(stderr,
+						"PSIZE gathering only for own "
+						"processes\n");
+					sleep(3);
+				}
+
 				break;
 
                            case MGETWCHAN:	/* obtain wchan string?       */
@@ -430,6 +456,15 @@ main(int argc, char *argv[])
 				rmspaces = 1;
 				break;
 
+			   case 'z':            /* prepend regex matching environment variables */
+				if (regcomp(&envregex, optarg, REG_NOSUB|REG_EXTENDED))
+				{
+					fprintf(stderr, "Invalid environment regular expression!");
+					prusage(argv[0]);
+				}
+				prependenv = 1;
+				break;
+
 			   default:		/* gather other flags */
 				flaglist[i++] = c;
 			}
@@ -545,7 +580,7 @@ main(int argc, char *argv[])
 	initifprop();
 
 	/*
- 	** open socket to the IP layer to issue getsockopt() calls later on
+	** open socket to the IP layer to issue getsockopt() calls later on
 	*/
 	netatop_ipopen();
 
@@ -846,6 +881,11 @@ engine(void)
 		deviattask(curtpres,  ntaskpres, curpexit,  nprocexit,
 		                      &devtstat, devsstat);
 
+		if (supportflags & NETATOPBPF) {
+			g_hash_table_destroy(ghash_net);
+			ghash_net = NULL;
+		}
+
 		/*
 		** activate the installed print-function to visualize
 		** the deviations
@@ -863,8 +903,9 @@ engine(void)
 
 		free(curtpres);
 
-		if (nprocexitnet > 0)
-			netatop_exiterase();
+		if ((supportflags & NETATOPD) && (nprocexitnet > 0)) {
+				netatop_exiterase();
+		}
 
 		if (gp)
 			 free(gp);
@@ -896,7 +937,7 @@ prusage(char *myname)
 	printf("\t\tor\n");
 	printf("Usage: %s -w  file  [-S] [-%c] [interval [samples]]\n",
 					myname, MALLPROC);
-	printf("       %s -r [file] [-b [YYYYMMDD]hhmm] [-e [YYYYMMDD]hhmm] [-flags]\n",
+	printf("       %s -r [file] [-b [YYYYMMDD]hhmm[ss]] [-e [YYYYMMDD]hhmm[ss]] [-flags]\n",
 					myname);
 	printf("\n");
 	printf("\tgeneric flags:\n");
@@ -914,6 +955,8 @@ prusage(char *myname)
 			MRMSPACES);
 	printf("\t  -L  alternate line length (default 80) in case of "
 			"non-screen output\n");
+	printf("\t  -z  prepend regex matching environment variables to "
+                        "command line\n");
 
 	if (vis.show_usage)
 		(*vis.show_usage)();
