@@ -24,6 +24,8 @@
 #ifndef __ATOP__
 #define __ATOP__
 
+#include <time.h>
+
 #define	EQ		0
 #define SECONDSINDAY	86400
 #define RAWNAMESZ	256
@@ -60,7 +62,7 @@ struct netpertask;
 #define RRNETATOPD	0x0008
 #define RRACCTACTIVE	0x0010
 #define RRIOSTAT	0x0020
-#define RRDOCKSTAT	0x0040
+#define RRCONTAINERSTAT	0x0040
 #define RRGPUSTAT	0x0080
 #define RRCGRSTAT	0x0100
 
@@ -126,9 +128,11 @@ extern int		almostcrit;
 #define	IOSTAT		0x00000004
 #define	NETATOP		0x00000010
 #define	NETATOPD	0x00000020
-#define	DOCKSTAT	0x00000040
+#define	CONTAINERSTAT	0x00000040
 #define	GPUSTAT		0x00000080
 #define	CGROUPV2	0x00000100
+#define	NETATOPBPF	0x00001000
+
 
 /*
 ** in rawlog file, the four least significant bits 
@@ -199,6 +203,7 @@ void		cleanstop(int);
 int		getpidwidth(void);
 void		prusage(char *);
 
+int		rootprivs(void);
 int		droprootprivs(void);
 void		regainrootprivs(void);
 FILE 		*fopen_tryroot(const char *, const char *);
@@ -211,6 +216,12 @@ unsigned int	netatop_exitstore(void);
 void		netatop_exiterase(void);
 void		netatop_exithash(char);
 void		netatop_exitfind(unsigned long, struct tstat *, struct tstat *);
+
+void		netatop_bpf_ipopen(void);
+void		netatop_bpf_probe(void);
+void		netatop_bpf_gettask(void);
+void		netatop_bpf_exitfind(unsigned long, struct tstat *, struct tstat *);
+
 void		set_oom_score_adj(void);
 int		run_in_guest(void);
 
@@ -221,4 +232,7 @@ void		do_atopsarflags(char *, char *);
 int		netlink_open(void);
 int		netlink_recv(int, int);
 
+int		getutsname(struct tstat *);
+void		resetutsname(void);
+
 #endif
