@@ -85,11 +85,11 @@ struct pridef {
 	char    wanted;         /* selected option (boolean)              */
 	char    *cntcat;        /* used categories of counters            */
 	char    flag;           /* flag on command line                   */
-	void    (*prihead)();   /* print header of list                   */
+	void    (*prihead)(int, int, int);   /* print header of list      */
 	int     (*priline)(struct sstat *, struct tstat *, struct tstat **,
 		           int, time_t, time_t, time_t,
 		           int, int, int, char *,
-        	           int, int, int, int, int, int);
+        	           int, int, int, int, int, int, int);
 		                /* print counters per line (excl. time)   */
 	char    *about;         /* statistics about what                  */
 };
@@ -369,8 +369,9 @@ atopsar(int argc, char *argv[])
 	*/
 	rlim.rlim_cur	= RLIM_INFINITY;
 	rlim.rlim_max	= RLIM_INFINITY;
-	(void) setrlimit(RLIMIT_MEMLOCK, &rlim);
-	(void) mlockall(MCL_CURRENT|MCL_FUTURE);
+
+	if (setrlimit(RLIMIT_MEMLOCK, &rlim) == 0)
+		(void) mlockall(MCL_CURRENT|MCL_FUTURE);
 
 	/*
 	** increment CPU scheduling-priority to get reliable samples (also
@@ -606,7 +607,7 @@ reportlive(time_t curtime, int numsecs, struct sstat *ss)
 				numsecs, numsecs*hertz, hertz,
 				osvers, osrel, ossub,
 				stampalways ? timebuf : "        ",
-	                        0, 0, 0, 0, 0, 0) )
+	                        0, 0, 0, 0, 0, 0, 0) )
 			{
 				/*
 				** print line has failed;
@@ -677,7 +678,7 @@ reportlive(time_t curtime, int numsecs, struct sstat *ss)
 					numsecs, numsecs*hertz, hertz,
 					osvers, osrel, ossub, 
 		                        stampalways ? timebuf : "        ",
-	                        	0, 0, 0, 0, 0, 0) ) )
+	                        	0, 0, 0, 0, 0, 0, 0) ) )
 		{
 			/*
 			** print line has failed;
@@ -727,7 +728,8 @@ reportraw(time_t curtime, int numsecs,
 	unsigned int		rv;
 	static unsigned int	curline, headline, sampsum,
 				totalsec, totalexit, lastnpres,
-				lastntrun, lastntslpi, lastntslpu, lastnzomb;
+				lastntrun, lastntslpi, lastntslpu,
+				lastntidle, lastnzomb;
 	static time_t		lasttime;
 	static struct sstat	totsyst;
 
@@ -825,7 +827,8 @@ reportraw(time_t curtime, int numsecs,
 				totalsec, totalsec*hertz, hertz,
 			        osvers, osrel, ossub,
 		                stampalways ? timebuf : "        ",
-	                        lastnpres, lastntrun, lastntslpi, lastntslpu,
+	                        lastnpres, lastntrun, lastntslpi,
+				lastntslpu, lastntidle,
 				totalexit, lastnzomb);
 
 			if (rv == 0)
@@ -879,6 +882,7 @@ reportraw(time_t curtime, int numsecs,
 	               		stampalways ? timebuf : "        ",
 				devtstat->ntaskall, devtstat->totrun,
 				devtstat->totslpi, devtstat->totslpu,
+				devtstat->totidle, 
 				nexit, devtstat->totzombie);
 
 		if (rv == 0)
@@ -919,6 +923,7 @@ reportraw(time_t curtime, int numsecs,
 		lastntrun  = devtstat->totrun;
 		lastntslpi = devtstat->totslpi;
 		lastntslpu = devtstat->totslpu;
+		lastntidle = devtstat->totidle;
 		lastnzomb  = devtstat->totzombie;
 
 		/*
@@ -938,6 +943,7 @@ reportraw(time_t curtime, int numsecs,
 					stampalways ? timebuf : "        ",
 					devtstat->ntaskall, devtstat->totrun,
 					devtstat->totslpi, devtstat->totslpu,
+					devtstat->totidle,
 					totalexit, devtstat->totzombie);
 
 			if (rv == 0)
@@ -1024,9 +1030,9 @@ pratopsaruse(char *myname)
 	fprintf(stderr,
 		"\t  -R  summarize <cnt> samples into one sample\n");
 	fprintf(stderr,
-		"\t  -b  begin  showing data from  specified time as [YYYYMMDD]hhmm\n");
+		"\t  -b  begin  showing data from  specified time as [YYYYMMDD]hhmm[ss]\n");
 	fprintf(stderr,
-		"\t  -e  finish showing data after specified time as [YYYYMMDD]hhmm\n");
+		"\t  -e  finish showing data after specified time as [YYYYMMDD]hhmm[ss]\n");
 	fprintf(stderr,
 		"\t  -S  print timestamp on every line in case of more "
 		"resources\n");
@@ -1220,7 +1226,8 @@ static int
 cpuline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	register int	i, nlines = 1;
 	count_t		cputot;
@@ -1321,7 +1328,8 @@ static int
 gpuline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	static char	firstcall = 1;
 	register long	i, nlines = 0;
@@ -1415,7 +1423,8 @@ static int
 procline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	printf("%7.0lf %9.0lf %9.2lf  %8.2lf %8.2lf  %8.2lf\n",
 		(double)ss->cpu.csw    / deltasec,
@@ -1431,7 +1440,7 @@ procline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
 static void
 taskhead(int osvers, int osrel, int ossub)
 {
-	printf("clones/s pexit/s  curproc curzomb    thrrun thrslpi thrslpu "
+	printf("clones/s pexit/s  curproc curzomb   trun  tslpi tslpu tidle "
 	       "_procthr_");
 }
 
@@ -1439,7 +1448,8 @@ static int
 taskline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	if (ppres == 0)
 	{
@@ -1449,10 +1459,11 @@ taskline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
 
 	if (ts)		/* process statistics available */
 	{
-		printf("%8.2lf %7.2lf  %7d %7d    %6d %7d %7d\n",
+		printf("%8.2lf %7.2lf  %7d %7d %6d %6d %5d %5d\n",
 			(double)ss->cpu.nprocs / deltasec,
 			(double)pexit          / deltasec,
-			nactproc-pexit, pzombie, ntrun, ntslpi, ntslpu);
+			nactproc-pexit, pzombie,
+			ntrun, ntslpi, ntslpu, ntidle);
 	}
 	else
 	{
@@ -1479,7 +1490,8 @@ static int
 memline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	unsigned int	mbadness, sbadness;
 
@@ -1529,7 +1541,8 @@ static int
 swapline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	unsigned int	badness;
 
@@ -1578,7 +1591,8 @@ static int
 psiline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	// calculate pressure percentages for entire interval
 	unsigned int	csperc  = ss->psi.cpusome.total/(deltatic*10000/hz);
@@ -1751,7 +1765,8 @@ static int
 lvmline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	return gendskline(ss, tstamp, 'l');
 }
@@ -1760,7 +1775,8 @@ static int
 mddline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	return gendskline(ss, tstamp, 'm');
 }
@@ -1769,7 +1785,8 @@ static int
 dskline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	return gendskline(ss, tstamp, 'd');
 }
@@ -1788,7 +1805,8 @@ static int
 nfmline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	static char	firstcall = 1;
 	register long	i, nlines = 0;
@@ -1852,7 +1870,8 @@ static int
 nfcline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	printf("%10.2lf  %10.2lf  %10.2lf %10.2lf  %12.2lf\n",
 		(double)ss->nfs.client.rpccnt        / deltasec,
@@ -1875,7 +1894,8 @@ static int
 nfsline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	printf("%7.2lf %10.2lf %10.2lf %6.2lf %7.2lf %9.2lf %8.2lf\n",
 		(double)ss->nfs.server.rpccnt    / deltasec,
@@ -1903,7 +1923,8 @@ static int
 ibline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	static char	firstcall = 1;
 	register long	i, nlines = 0;
@@ -1984,7 +2005,8 @@ static int
 ifline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	static char	firstcall = 1;
 	register long	i, nlines = 0;
@@ -2116,7 +2138,8 @@ static int
 IFline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	static char	firstcall = 1;
 	register long	i, nlines = 0;
@@ -2178,7 +2201,8 @@ static int
 ipv4line(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	printf("%8.1lf %8.1lf %11.1lf %9.1lf %9.1lf %11.1lf\n", 
 		(double)ss->net.ipv4.InReceives  / deltasec,
@@ -2201,7 +2225,8 @@ static int
 IPv4line(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	printf("    %5.1lf %6.1lf %6.1lf %6.1lf %7.1lf %7.1lf  "
 	       "    %5.1lf %5.1lf\n", 
@@ -2230,7 +2255,8 @@ static int
 icmpv4line(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	printf("%7.1lf %8.1lf  %8.2lf %8.2lf  %8.2lf %8.2lf\n", 
 		(double)ss->net.icmpv4.InMsgs      / deltasec, 
@@ -2253,7 +2279,8 @@ static int
 ICMPv4line(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	printf("%6.2lf %5.2lf %5.2lf %5.2lf %5.2lf "
 	       "%6.2lf %5.2lf %5.2lf %5.2lf %5.2lf\n", 
@@ -2284,7 +2311,8 @@ static int
 udpv4line(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	printf("%9.1lf %10.1lf   %7.2lf %9.2lf\n",
 		(double)ss->net.udpv4.InDatagrams  / deltasec,
@@ -2308,7 +2336,8 @@ static int
 ipv6line(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	printf("%8.1lf %8.1lf %6.1lf %7.1lf %9.1lf %9.1lf %9.1lf\n", 
 		(double)ss->net.ipv6.Ip6InReceives   / deltasec,
@@ -2332,7 +2361,8 @@ static int
 IPv6line(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	printf("    %5.1lf %6.1lf %6.1lf %6.1lf %7.1lf %7.1lf  "
 	       "    %5.1lf %5.1lf\n", 
@@ -2361,7 +2391,8 @@ static int
 icmpv6line(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	printf("%7.1lf %8.1lf %7.2lf %8.2lf %8.2lf %8.2lf %8.2lf\n", 
 		(double)ss->net.icmpv6.Icmp6InMsgs                  / deltasec, 
@@ -2386,7 +2417,8 @@ static int
 ICMPv6line(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	printf("%7.2lf %7.2lf %7.2lf %5.2lf %5.2lf "
 	       "%5.2lf %5.2lf %5.2lf %5.2lf\n", 
@@ -2416,7 +2448,8 @@ static int
 udpv6line(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	printf("%9.1lf %10.1lf   %7.2lf %9.2lf\n",
 		(double)ss->net.udpv6.Udp6InDatagrams  / deltasec,
@@ -2440,7 +2473,8 @@ static int
 tcpline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	printf("%8.1lf %9.1lf  %9.1lf %9.1lf  %7lld\n",
 		(double)ss->net.tcp.InSegs       / deltasec,
@@ -2462,7 +2496,8 @@ static int
 TCPline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	printf("%7.1lf  %9.1lf  %9.1lf  %12.1lf  %10.1lf\n",
 		(double)ss->net.tcp.InErrs       / deltasec,
@@ -2485,7 +2520,8 @@ static int
 httpline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	printf("%10.2lf  %8.2lf  %9.2lf    %11d %11d\n",
 		(double)ss->www.accesses      / deltasec,
@@ -2513,7 +2549,8 @@ static int
 topcline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	count_t	availcpu;
 
@@ -2577,7 +2614,8 @@ static int
 topmline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	count_t		availmem;
 
@@ -2633,7 +2671,8 @@ static int
 topdline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	int		i;
 	count_t		availdsk;
@@ -2705,7 +2744,8 @@ static int
 topnline(struct sstat *ss, struct tstat *ts, struct tstat **ps, int nactproc,
         time_t deltasec, time_t deltatic, time_t hz,
         int osvers, int osrel, int ossub, char *tstamp,
-        int ppres,  int ntrun, int ntslpi, int ntslpu, int pexit, int pzombie)
+        int ppres,  int ntrun, int ntslpi, int ntslpu, int ntidle,
+	int pexit, int pzombie)
 {
 	int		i;
 	count_t		availnet;
