@@ -4,7 +4,7 @@
 ** The program 'atop' offers the possibility to view the activity of
 ** the system on system-level as well as process-level.
 ** 
-** This source-file contains function for bar graph representation of
+** This source-file contains functions for bar graph representation of
 ** system-level statistics about processors, memory, disks and network
 ** interfaces.
 ** ==========================================================================
@@ -103,6 +103,7 @@
 // the other.
 /////////////////////////////////////////////////////////////////////////////
 
+#include <sys/types.h>
 #include <curses.h>
 #include <locale.h>
 #include <string.h>
@@ -112,6 +113,7 @@
 #include <sys/utsname.h>
 
 #include "atop.h"
+#include "photoproc.h"
 #include "showgeneric.h"
 #include "photosyst.h"
 
@@ -551,10 +553,10 @@ do_cpubars(struct sstat *sstat, int nsecs, char initlabels, char mono)
 		labellen = snprintf(buf, sizeof buf, "%d", numcpus);
 
 		vertvals = malloc(numlabs * sizeof(struct vertval));
-		ptrverify(vertvals, "Malloc failed for %ld vertval structs failed\n", numlabs);
+		ptrverify(vertvals, "Malloc failed for %d vertval structs\n", numlabs);
 
 		labarea = malloc(numlabs * (labellen+1));
-		ptrverify(labarea, "Malloc failed for %ld CPU labels failed\n", numlabs);
+		ptrverify(labarea, "Malloc failed for %d CPU labels\n", numlabs);
 
 		// create new X axis labels
 		//
@@ -734,10 +736,10 @@ do_dskbars(struct sstat *sstat, int nsecs, char initlabels, char mono)
 		numdisks = sstat->dsk.ndsk;
 
 		vertvals = malloc(numdisks * sizeof(struct vertval));
-		ptrverify(vertvals, "Malloc failed for %ld vertval structs failed\n", numdisks);
+		ptrverify(vertvals, "Malloc failed for %d vertval structs\n", numdisks);
 
 		labarea = malloc(numdisks * (MAXLABLEN+1));
-		ptrverify(labarea, "Malloc failed for %ld disk labels failed\n", numdisks);
+		ptrverify(labarea, "Malloc failed for %d disk labels\n", numdisks);
 
 		// create new X axis labels
 		//
@@ -931,10 +933,10 @@ addifscale(char *interface, int scale)
 		hash += *p;
 
 	isp = malloc(sizeof(struct ifscale));
-	ptrverify(isp, "Malloc failed for ifscale struct failed\n");
+	ptrverify(isp, "Malloc failed for ifscale struct\n");
 
 	isp->interface 	= malloc(len+1);
-	ptrverify(isp->interface, "Malloc failed for ifscale name failed\n");
+	ptrverify(isp->interface, "Malloc failed for ifscale name\n");
 	strcpy(isp->interface, interface);
 
 	isp->next 	= ishash[hash&(ISNUM-1)];
@@ -1011,10 +1013,10 @@ do_netbars(struct sstat *sstat, int nsecs, char initlabels, char lower)
 		// create new label space
 		//
 		netvals = malloc(numints * sizeof(struct netval));
-		ptrverify(netvals, "Malloc failed for %ld netvals structs failed\n", numints);
+		ptrverify(netvals, "Malloc failed for %ld netvals structs\n", numints);
 
 		labarea = malloc(numints * (MAXLABLEN+1));
-		ptrverify(labarea, "Malloc failed for %ld interface labels failed\n", numints);
+		ptrverify(labarea, "Malloc failed for %ld interface labels\n", numints);
 
 		// create new X axis labels
 		//
@@ -1736,12 +1738,12 @@ drawmemory(struct perwindow *w, struct sstat *sstat, int nsecs,
 	static time_t	lastoomkills;
 
 	long long	totalmem, cachemem, shmemrss, tmpfsmem,
-			slabmem, freemem;
+			slabmem, freemem, hugefree, hugeused, shmrssreal;
 	long long	totalswp, shmemswp, freeswp;
 	char		scanseverity, swapseverity, killseverity;
 	int 		curline=0, barlines, color;
 	int 		usedlines, freelines, cachelines, tmpfslines,
-			slablines, shmemlines;
+			slablines, shmemlines, hugelines;
 	int		memorycol = 1,
 			swapcol   = memorycol + MEMORYBARSZ + 1,
 			eventcol  = swapcol   + SWAPBARSZ   + 2;
@@ -1749,22 +1751,51 @@ drawmemory(struct perwindow *w, struct sstat *sstat, int nsecs,
 	char		formatbuf[16];
 
 	// calculate all memory values, keeping in mind:
+	//
+	// - shmem		resident System V shared memory
+	// 				including resident tmpfs (POSIX shamem)
+	// 				excluding static huge pages
+	//
 	// - shmrss		resident System V shared memory
-	// - shmem		resident System V shared memory + resident tmpfs
+	// 				including static huge pages
+	//
 	// - cachemem		page cache including shmem
 	//
 	totalmem	=  sstat->mem.physmem * pagesize;
+
 	cachemem	= (sstat->mem.cachemem + sstat->mem.buffermem -
 			   sstat->mem.shmem)  * pagesize;
+
 	shmemrss	=  sstat->mem.shmrss  * pagesize;
-	tmpfsmem	= (sstat->mem.shmem - sstat->mem.shmrss) * pagesize;
+
 	slabmem		=  sstat->mem.slabmem * pagesize;
+
 	freemem		=  sstat->mem.freemem * pagesize;
 
+	hugefree	=  sstat->mem.sfreehugepage * sstat->mem.shugepagesz +
+			   sstat->mem.lfreehugepage * sstat->mem.lhugepagesz;
+
 	totalswp	=  sstat->mem.totswap * pagesize;
+
 	shmemswp	=  sstat->mem.shmswp  * pagesize;
+
 	freeswp		=  sstat->mem.freeswap* pagesize;
 
+	// assumption:	most of static huge pages use for SYSV shared memory,
+	// 		although static hige pages can also be used for mmap()
+	//
+	hugeused	= (sstat->mem.stothugepage - sstat->mem.sfreehugepage)
+							* sstat->mem.shugepagesz +
+			  (sstat->mem.ltothugepage - sstat->mem.lfreehugepage)
+							* sstat->mem.lhugepagesz;
+							
+	shmrssreal	= (sstat->mem.shmrss * pagesize) - hugeused;	// in bytes!
+
+	if (shmrssreal < 0)	// (partly) wrong assumption about static huge pages
+		shmrssreal = 0;
+
+	tmpfsmem	= (sstat->mem.shmem - sstat->mem.shmswp) * pagesize - shmrssreal / pagesize;
+
 	// determine severity for pagescans, swapouts and oomkills
 	// 'n' - normal,
 	// 'w' - warning,
@@ -1814,7 +1845,8 @@ drawmemory(struct perwindow *w, struct sstat *sstat, int nsecs,
 	tmpfslines = (tmpfsmem + valperunit/2) / valperunit;
 	slablines  = (slabmem  + valperunit/2) / valperunit;
 	cachelines = (cachemem + valperunit/2) / valperunit;
-	usedlines  =  barlines - freelines - shmemlines -
+	hugelines  = (hugefree + valperunit/2) / valperunit;
+	usedlines  =  barlines - freelines - shmemlines - hugelines -
 	              tmpfslines - slablines - cachelines;
 
 	// wipe window contents
@@ -1831,6 +1863,13 @@ drawmemory(struct perwindow *w, struct sstat *sstat, int nsecs,
 	curline += drawmemlines(w, curline, memorycol, cachelines,
 			MEMORYBARSZ, COLORMEMCACH, "pagecache", NULL);
 
+	// draw lines for free static huge pages memory
+	// (occupied static huge pages are already part of processes
+	// or shared memory)
+	//
+	curline += drawmemlines(w, curline, memorycol, hugelines,
+			MEMORYBARSZ, COLORMEMHUGE, "free huge", "pages");
+
 	// draw lines for tmpfs memory
 	//
 	curline += drawmemlines(w, curline, memorycol, tmpfslines,
@@ -2055,7 +2094,7 @@ drawevent(struct perwindow *w, int line, int column, int color,
 
 	line -= 1;
        	wattron(w->win, A_BOLD);
-	mvwprintw(w->win, line, column, text);
+	mvwprintw(w->win, line, column, "%s", text);
        	wattroff(w->win, A_BOLD);
 
 	colorswoff(w->win, color);
@@ -2105,7 +2144,7 @@ headergetch(time_t curtime, int nsecs, char *statusmsg, int statuscol)
 	{
         	colorswon(headwin, statuscol);
 		wattron(headwin, A_REVERSE);
-		mvwprintw(headwin, 0, statcol, statusmsg);
+		mvwprintw(headwin, 0, statcol, "%s", statusmsg);
 		wattroff(headwin, A_REVERSE);
         	colorswoff(headwin, statuscol);
 	}
@@ -2328,7 +2367,7 @@ getwininput(char *prompt, char *answer, int maxanswer, char numerical)
 
 	// show the prompt
 	//
-	mvwprintw(mywin, 1, 1, prompt);
+	mvwprintw(mywin, 1, 1, "%s", prompt);
 
 	// prepare reading input
 	//
