@@ -444,7 +444,12 @@ static void json_print_MEM(char *hp, struct sstat *ss, struct tstat *ps, int nac
 		"\"shmswp\": %lld, "
 		"\"hugepagesz\": %lld, "
 		"\"tothugepage\": %lld, "
-		"\"freehugepage\": %lld}",
+		"\"freehugepage\": %lld, "
+		"\"lhugepagesz\": %lld, "
+		"\"ltothugepage\": %lld, "
+		"\"lfreehugepage\": %lld, "
+		"\"availablemem\": %lld, "
+		"\"anonhugepage\": %lld}",
 		hp,
 		ss->mem.physmem * pagesize,
 		ss->mem.freemem * pagesize,
@@ -457,9 +462,14 @@ static void json_print_MEM(char *hp, struct sstat *ss, struct tstat *ps, int nac
 		ss->mem.shmem * pagesize,
 		ss->mem.shmrss * pagesize,
 		ss->mem.shmswp * pagesize,
-		ss->mem.hugepagesz,
-		ss->mem.tothugepage,
-		ss->mem.freehugepage);
+		ss->mem.shugepagesz,
+		ss->mem.stothugepage,
+		ss->mem.sfreehugepage,
+		ss->mem.lhugepagesz,
+		ss->mem.ltothugepage,
+		ss->mem.lfreehugepage,
+		ss->mem.availablemem * pagesize,
+		ss->mem.anonhugepage * pagesize);
 }
 
 static void json_print_SWP(char *hp, struct sstat *ss, struct tstat *ps, int nact)
@@ -845,7 +855,8 @@ static void json_print_NUM(char *hp, struct sstat *ss, struct tstat *ps, int nac
 			"\"slabmem\": %lld, "
 			"\"slabreclaim\": %lld, "
 			"\"shmem\": %lld, "
-			"\"tothp\": %lld}",
+			"\"tothp\": %lld, "
+			"\"freehp\": %lld}",
 			ss->memnuma.numa[i].numanr,
 			ss->memnuma.numa[i].frag * 100.0,
 			ss->memnuma.numa[i].totmem * pagesize,
@@ -857,7 +868,8 @@ static void json_print_NUM(char *hp, struct sstat *ss, struct tstat *ps, int nac
 			ss->memnuma.numa[i].slabmem * pagesize,
 			ss->memnuma.numa[i].slabreclaim * pagesize,
 			ss->memnuma.numa[i].shmem * pagesize,
-			ss->memnuma.numa[i].tothp * ss->mem.hugepagesz);
+			ss->memnuma.numa[i].tothp * ss->mem.shugepagesz,
+			ss->memnuma.numa[i].freehp * ss->mem.shugepagesz);
 	}
 
 	printf("]");
@@ -976,11 +988,13 @@ static void json_print_PRG(char *hp, struct sstat *ss, struct tstat *ps, int nac
 			"\"nthrrun\": %d, "
 			"\"nthrslpi\": %d, "
 			"\"nthrslpu\": %d, "
+			"\"nthridle\": %d, "
 			"\"euid\": %d, "
 			"\"egid\": %d, "
 			"\"elaps\": \"%ld\", "
 			"\"isproc\": %d, "
-			"\"cid\": \"%.19s\"}",
+			"\"cid\": \"%.19s\", "
+			"\"cgroup\": \"%s\"}",
 			ps->gen.pid,
 			ps->gen.name,
 			ps->gen.state,
@@ -996,11 +1010,13 @@ static void json_print_PRG(char *hp, struct sstat *ss, struct tstat *ps, int nac
 			ps->gen.nthrrun,
 			ps->gen.nthrslpi,
 			ps->gen.nthrslpu,
+			ps->gen.nthridle,
 			ps->gen.euid,
 			ps->gen.egid,
 			ps->gen.elaps,
 			!!ps->gen.isproc, /* convert to boolean */
-			ps->gen.container[0] ? ps->gen.container:"-");
+			ps->gen.utsname[0] ? ps->gen.utsname:"-",
+			ps->gen.cgpath[0] ? ps->gen.cgpath:"-");
 	}
 
 	printf("]");
@@ -1030,7 +1046,8 @@ static void json_print_PRC(char *hp, struct sstat *ss, struct tstat *ps, int nac
 			"\"blkdelay\": %lld, "
 			"\"nvcsw\": %llu, "
 			"\"nivcsw\": %llu, "
-			"\"sleepavg\": %d}",
+			"\"sleepavg\": %d, "
+			"\"cgroup\": \"%s\"}",
 			ps->gen.pid,
 			ps->cpu.utime,
 			ps->cpu.stime,
@@ -1043,7 +1060,8 @@ static void json_print_PRC(char *hp, struct sstat *ss, struct tstat *ps, int nac
 			ps->cpu.blkdelay*1000/hertz,
 			ps->cpu.nvcsw,
 			ps->cpu.nivcsw,
-			ps->cpu.sleepavg);
+			ps->cpu.sleepavg,
+			ps->gen.cgpath[0] ? ps->gen.cgpath:"-");
 	}
 
 	printf("]");
@@ -1074,7 +1092,8 @@ static void json_print_PRM(char *hp, struct sstat *ss, struct tstat *ps, int nac
 			"\"vstack\": %lld, "
 			"\"vlock\": %lld, "
 			"\"vswap\": %lld, "
-			"\"pmem\": %lld}",
+			"\"pmem\": %lld, "
+			"\"cgroup\": \"%s\"}",
 			ps->gen.pid,
 			ps->mem.vmem,
 			ps->mem.rmem,
@@ -1089,7 +1108,8 @@ static void json_print_PRM(char *hp, struct sstat *ss, struct tstat *ps, int nac
 			ps->mem.vlock,
 			ps->mem.vswap,
 			ps->mem.pmem == (unsigned long long)-1LL ?
-			0:ps->mem.pmem);
+			0:ps->mem.pmem,
+			ps->gen.cgpath[0] ? ps->gen.cgpath:"-");
 	}
 
 	printf("]");
