@@ -78,6 +78,9 @@
 /* recognize numa node */
 #define	NUMADIR	"/sys/devices/system/node"
 
+/* recognize large huge pages */
+#define	HUGEPAGEDIR	"/sys/kernel/mm/hugepages"
+
 /* recognize LLC monitor data */
 #define LLCDIR	"/sys/fs/resctrl/mon_data"
 #define L3SIZE	"/sys/devices/system/cpu/cpu0/cache/index3/size"
@@ -100,7 +103,6 @@ static void	getperfevents(struct cpustat *);
 
 static int	get_infiniband(struct ifbstat *);
 static int	get_ksm(struct sstat *);
-static int	get_zswap(struct sstat *);
 
 static int	isdisk(unsigned int, unsigned int,
 			char *, struct perdsk *, int);
@@ -277,7 +279,13 @@ photosyst(struct sstat *si)
 	static char	part_stats = 1; /* per-partition statistics ? */
 	static char	ib_stats = 1; 	/* InfiniBand statistics ? */
 	static char	ksm_stats = 1; 	
-	static char	zswap_stats = 1;
+
+	static char	*lhugepagetot;	/* name of large hugepage dir total */
+					/* might be -1 if not applicable    */
+	static char	*lhugepagefree;	/* name of large hugepage dir free  */
+					/* might be -1 if not applicable    */
+	static unsigned int hpsize;
+
 
 	register int	i, nr, j;
 	count_t		cnts[MAXCNT];
@@ -661,6 +669,16 @@ photosyst(struct sstat *si)
 				si->mem.pgmigrate = cnts[0];
 				continue;
 			}
+
+			if ( strcmp("zswpout", nam) == EQ) {
+				si->mem.zswouts = cnts[0];
+				continue;
+			}
+
+			if ( strcmp("zswpin", nam) == EQ) {
+				si->mem.zswins = cnts[0];
+				continue;
+			}
 		}
 
 		fclose(fp);
@@ -745,6 +763,11 @@ photosyst(struct sstat *si)
 							cnts[0]*1024/pagesize;
 					}
 				}
+			else	if (strcmp("MemAvailable:", nam) == EQ)
+				{
+					si->mem.availablemem  =
+							cnts[0]*1024/pagesize;
+				}
 			else	if (strcmp("Buffers:", nam) == EQ)
 				{
 					if (si->mem.buffermem  == (count_t)-1)
@@ -797,28 +820,137 @@ photosyst(struct sstat *si)
 					si->mem.commitlim = cnts[0]*1024/
 								pagesize;
 				}
+			else	if (strcmp("AnonHugePages:", nam) == EQ)
+				{
+					si->mem.anonhugepage = cnts[0]*1024/
+								pagesize;
+				}
 			else	if (strcmp("HugePages_Total:", nam) == EQ)
 				{
-					si->mem.tothugepage = cnts[0];
+					si->mem.stothugepage = cnts[0];
 				}
 			else	if (strcmp("HugePages_Free:", nam) == EQ)
 				{
-					si->mem.freehugepage = cnts[0];
+					si->mem.sfreehugepage = cnts[0];
 				}
 			else	if (strcmp("Hugepagesize:", nam) == EQ)
 				{
-					si->mem.hugepagesz = cnts[0]*1024;
+					si->mem.shugepagesz = cnts[0]*1024;
 				}
 			else	if (strcmp("PageTables:", nam) == EQ)
 				{
 					si->mem.pagetables = cnts[0]*1024/
 								pagesize;
 				}
+			else	if (strcmp("Zswap:", nam) == EQ)
+				{
+					si->mem.zswap = cnts[0]*1024/
+								pagesize;
+				}
+			else	if (strcmp("Zswapped:", nam) == EQ)
+				{
+					si->mem.zswapped = cnts[0]*1024/
+								pagesize;
+				}
 		}
 
 		fclose(fp);
 	}
 
+	/*
+ 	** gather values of larger huge pages that are not provided
+	** by /proc/meminfo
+	**
+	** all required hugepage info can be found in:
+	**
+	**    /sys/kernel/mm/hugepages/hugepages-1048576kB
+	**                                                /free_hugepages
+	**                                                /nr_hugepages
+	**
+	**    /sys/kernel/mm/hugepages/hugepages-2048kB
+	**                                                /free_hugepages
+	**                                                /nr_hugepages
+	**
+	** the info about the smaller hugepages (2M) is already
+	** read from /proc/memory
+	** 
+	** first time initialization:
+	**   find out if there is a large hugepage directory
+	*/
+	if (!lhugepagetot)
+	{
+		lhugepagetot  = (char *) -1;	// should be overwritten
+		lhugepagefree = (char *) -1;	// should be overwritten
+
+		dirp = opendir(HUGEPAGEDIR);
+
+		if (dirp)
+		{
+			/*
+			** read directory entries that start with "hugepages-"
+			*/
+			while ( (dentry = readdir(dirp)) )
+			{
+				if (strncmp(dentry->d_name, "hugepages-", 10))
+					continue;
+
+				hpsize = strtoul(dentry->d_name+10, NULL, 0) * 1024;
+
+				if (hpsize == si->mem.shugepagesz)
+					continue;	// values already known
+
+				/*
+ 				** directory name of larger hugepages found:
+				** store for use in subsequent intervals
+				*/
+				lhugepagetot = malloc(sizeof HUGEPAGEDIR + 1 +
+							strlen(dentry->d_name) + 1 +
+							sizeof "nr_hugepages" + 1);
+
+				ptrverify(lhugepagetot,
+					"Malloc failed for huge page total");
+
+				sprintf(lhugepagetot, "%s/%s/nr_hugepages",
+							HUGEPAGEDIR, dentry->d_name);
+
+
+				lhugepagefree = malloc(sizeof HUGEPAGEDIR + 1 +
+							strlen(dentry->d_name) + 1 +
+							sizeof "free_hugepages" + 1);
+
+				ptrverify(lhugepagefree,
+					"Malloc failed for huge page free");
+
+				sprintf(lhugepagefree, "%s/%s/free_hugepages",
+							HUGEPAGEDIR, dentry->d_name);
+
+				break;
+			}
+
+			closedir(dirp);
+		}
+	}
+
+	// large hugepages for each interval:
+	//
+	if ( lhugepagetot != (char *)-1 && (fp = fopen(lhugepagetot, "r")) != NULL)
+	{
+		if ( fgets(linebuf, sizeof(linebuf), fp) != NULL)
+			nr = sscanf(linebuf, "%lld", &si->mem.ltothugepage);
+
+		fclose(fp);
+	}
+
+	if ( lhugepagefree != (char *)-1 && (fp = fopen(lhugepagefree, "r")) != NULL)
+	{
+		if ( fgets(linebuf, sizeof(linebuf), fp) != NULL)
+			nr = sscanf(linebuf, "%lld", &si->mem.lfreehugepage);
+
+		fclose(fp);
+	}
+
+	si->mem.lhugepagesz = hpsize;
+
 	/*
 	** gather vmware-related statistics from /sys/kernel/debug/vmmemctl
 	** (only present if balloon driver enabled) or from /proc/vmmemctl
@@ -927,6 +1059,8 @@ photosyst(struct sstat *si)
 						si->memnuma.numa[j].slabreclaim = cnts[1]*1024/pagesize;
 					else if ( strcmp("HugePages_Total:", nam) == EQ)
 						si->memnuma.numa[j].tothp = cnts[1];
+					else if ( strcmp("HugePages_Free:", nam) == EQ)
+						si->memnuma.numa[j].freehp = cnts[1];
 				}
 				fclose(fp);
 			}
@@ -1927,12 +2061,6 @@ photosyst(struct sstat *si)
 	if (ksm_stats)
 		ksm_stats = get_ksm(si);
 
-	/*
-	** get counters related to zswap
-	*/
-	if (zswap_stats)
-		zswap_stats = get_zswap(si);
-
 	/*
  	** return to original directory
 	*/
@@ -2482,58 +2610,6 @@ get_ksm(struct sstat *si)
 	return 1;
 }
 
-/*
-** retrieve zswap values (if switched on)
-*/
-static int
-get_zswap(struct sstat *si)
-{
-	FILE *fp;
-	char  state;
-
-	si->mem.zswtotpool = -1;
-	si->mem.zswstored  = -1;
-
-	if ((fp=fopen("/sys/module/zswap/parameters/enabled", "r")) != 0)
-	{
-		if (fscanf(fp, "%c", &state) == 1)
-		{
-			if (state != 'Y')
-			{
-				fclose(fp);
-				return 0; // no more calling
-			}
-		}
-
-		fclose(fp);
-	}
-
-	regainrootprivs();
-
-	if ((fp=fopen("/sys/kernel/debug/zswap/pool_total_size", "r")) != 0)
-	{
-		if (fscanf(fp, "%llu", &(si->mem.zswtotpool)) != 1)
-			si->mem.zswtotpool = 0;
-		else
-			si->mem.zswtotpool /= pagesize;
-
-		fclose(fp);
-	}
-
-	if ((fp=fopen("/sys/kernel/debug/zswap/stored_pages", "r")) != 0)
-	{
-		if (fscanf(fp, "%llu", &(si->mem.zswstored)) != 1)
-			si->mem.zswstored = 0;
-
-		fclose(fp);
-	}
-
-	if (! droprootprivs())
-		mcleanstop(42, "failed to drop root privs\n");
-
-	return 1;
-}
-
 
 #if	HTTPSTATS
 /*
