@@ -48,6 +48,7 @@
 #include <sys/uio.h>
 
 #include "atop.h"
+#include "photoproc.h"
 #include "showgeneric.h"
 #include "photoproc.h"
 #include "photosyst.h"
@@ -133,6 +134,7 @@ rawwrite(time_t curtime, int numsecs,
 	rr.totrun	= devtstat->totrun;
 	rr.totslpi	= devtstat->totslpi;
 	rr.totslpu	= devtstat->totslpu;
+	rr.totidle	= devtstat->totidle;
 	rr.totzomb	= devtstat->totzombie;
 	rr.scomplen	= scomplen;
 	rr.pcomplen	= pcomplen;
@@ -155,8 +157,8 @@ rawwrite(time_t curtime, int numsecs,
 	if (supportflags & CGROUPV2)
 		rr.flags |= RRCGRSTAT;
 
-	if (supportflags & DOCKSTAT)
-		rr.flags |= RRDOCKSTAT;
+	if (supportflags & CONTAINERSTAT)
+		rr.flags |= RRCONTAINERSTAT;
 
 	if (supportflags & GPUSTAT)
 		rr.flags |= RRGPUSTAT;
@@ -729,6 +731,7 @@ rawread(void)
  			devtstat.totrun		= rr.totrun;
  			devtstat.totslpi	= rr.totslpi;
  			devtstat.totslpu	= rr.totslpu;
+ 			devtstat.totidle	= rr.totidle;
  			devtstat.totzombie	= rr.totzomb;
 
 			/*
@@ -765,10 +768,10 @@ rawread(void)
 			else
 				supportflags &= ~CGROUPV2;
 
-			if (rr.flags & RRDOCKSTAT)
-				supportflags |=  DOCKSTAT;
+			if (rr.flags & RRCONTAINERSTAT)
+				supportflags |=  CONTAINERSTAT;
 			else
-				supportflags &= ~DOCKSTAT;
+				supportflags &= ~CONTAINERSTAT;
 
 			if (rr.flags & RRGPUSTAT)
 				supportflags |=  GPUSTAT;
