@@ -56,8 +56,6 @@
 #include "showgeneric.h"
 #include "showlinux.h"
 
-int getresuid(uid_t *ruid, uid_t *euid, uid_t *suid);
-
 static struct pselection procsel = {"", {USERSTUB, }, {0,},
                                     "", 0, { 0, },  "", 0, { 0, }, "", "" };
 static struct sselection syssel;
@@ -202,7 +200,7 @@ generic_samp(time_t curtime, int nsecs,
 				break;
 
 			   case MPROCNET:	// switch to text mode: network
-				if (supportflags & NETATOP)
+				if (supportflags & NETATOP || supportflags & NETATOPBPF)
 				{
 					showtype  = MPROCNET;
 
@@ -253,6 +251,9 @@ generic_samp(time_t curtime, int nsecs,
 			   case MPROCARG:	// switch to text mode: arguments
 				showtype  = MPROCARG;
 
+				displaymode = 'T';
+				break;
+
   			   default:
 				return retval;
 			}
@@ -269,8 +270,6 @@ text_samp(time_t curtime, int nsecs,
            struct devtstat *devtstat, struct sstat *sstat, 
            int nexit, unsigned int noverflow, char flag)
 {
-	char		*p;
-
 	register int	i, curline, statline, nproc;
 	int		firstproc = 0, plistsz, alistsz, killpid, killsig;
 	int		lastchar;
@@ -308,7 +307,7 @@ text_samp(time_t curtime, int nsecs,
 	int		nucum      = 0;
 	char		ulastorder = 0;
 
-	struct tstat	*tccumlist = 0;		// per container accumulation
+	struct tstat	*tccumlist = 0;		// per container/pod accumulation
 	struct tstat	**ccumlist = 0;
 	int		nccum      = 0;
 	char		clastorder = 0;
@@ -329,7 +328,7 @@ text_samp(time_t curtime, int nsecs,
 	/*
 	** sellist contains the pointers to the structs in tstat
 	** that are currently selected on basis of a particular
-	** username (regexp), program name (regexp), container name
+	** username (regexp), program name (regexp), container/pod name
 	** or suppressed exited procs
 	**
 	** this list will be allocated 'lazy'
@@ -456,7 +455,7 @@ text_samp(time_t curtime, int nsecs,
 			suppressexit 		      ? MSUPEXITS  : '-',
 			procsel.userid[0] != USERSTUB ? MSELUSER   : '-',
 			procsel.prognamesz	      ? MSELPROC   : '-',
-			procsel.container[0]	      ? MSELCONT   : '-',
+			procsel.utsname[0]	      ? MSELCONT   : '-',
 			procsel.pid[0] != 0	      ? MSELPID    : '-',
 			procsel.argnamesz	      ? MSELARG    : '-',
 			procsel.states[0]	      ? MSELSTATE  : '-',
@@ -584,18 +583,10 @@ text_samp(time_t curtime, int nsecs,
 				}
 				else
 				{
- 					uid_t ruid, euid, suid;
-
-					getresuid(&ruid, &euid, &suid);
-
-					if (suid == 0)
-					{
+					if (rootprivs())
 						viewmsg   = "Unrestricted view (privileged)";
-					}
 					else
-					{
 						viewmsg   = "Restricted view (unprivileged)";
-					}
 				}
 
 				if (screen)
@@ -801,7 +792,7 @@ text_samp(time_t curtime, int nsecs,
 
 			if ( procsel.userid[0] == USERSTUB &&
 			    !procsel.prognamesz            &&
-			    !procsel.container[0]          &&
+			    !procsel.utsname[0]            &&
 			    !procsel.states[0]             &&
 			    !procsel.argnamesz             &&
 			    !procsel.pid[0]                &&
@@ -1056,6 +1047,16 @@ text_samp(time_t curtime, int nsecs,
 			   case MBARGRAPH:
 				erase();
 				refresh();
+
+				if (tpcumlist) free(tpcumlist);
+				if (pcumlist)  free(pcumlist);
+				if (tucumlist) free(tucumlist);
+				if (ucumlist)  free(ucumlist);
+				if (tccumlist) free(tccumlist);
+				if (ccumlist)  free(ccumlist);
+				if (tsklist)   free(tsklist);
+				if (sellist)   free(sellist);
+
 				return lastchar;
 
 			   /*
@@ -1123,7 +1124,7 @@ text_samp(time_t curtime, int nsecs,
                                 move(statline, 0);
                                 clrtoeol();
                                 printw("Enter new time "
-				       "(format [YYYYMMDD]hhmm): ");
+				       "(format [YYYYMMDD]hhmm[ss]): ");
 
                                 branchtime[0] = '\0';
                                 scanw("%31s\n", branchtime);
@@ -1183,8 +1184,12 @@ text_samp(time_t curtime, int nsecs,
 			   case MSORTDSK:
 				if ( !(supportflags & IOSTAT) )
 				{
-					statmsg = "No disk-activity figures "
-					          "available; request ignored!";
+					if (rawreadflag)
+						statmsg = "No disk activity in "
+						          "raw file!";
+					else
+						statmsg = "No privileges to "
+						          "view disk activity!";
 					break;
 				}
 				showorder = MSORTDSK;
@@ -1195,9 +1200,9 @@ text_samp(time_t curtime, int nsecs,
 			   ** sort in network-activity order
 			   */
 			   case MSORTNET:
-				if ( !(supportflags & NETATOP) )
+				if ( !(supportflags & NETATOP || supportflags & NETATOPBPF))
 				{
-					statmsg = "Kernel module 'netatop' not "
+					statmsg = "Module 'netatop' or 'netatop-bpf' not "
 					          "active or no root privs; "
 					          "request ignored!";
 					break;
@@ -1250,8 +1255,12 @@ text_samp(time_t curtime, int nsecs,
 			   case MPROCDSK:
 				if ( !(supportflags & IOSTAT) )
 				{
-					statmsg = "No disk-activity figures "
-					          "available; request ignored!";
+					if (rawreadflag)
+						statmsg = "No disk activity in "
+						          "raw file!";
+					else
+						statmsg = "No privileges to "
+						          "view disk activity!";
 					break;
 				}
 
@@ -1267,9 +1276,9 @@ text_samp(time_t curtime, int nsecs,
 			   ** network-specific figures per process
 			   */
 			   case MPROCNET:
-				if ( !(supportflags & NETATOP) )
+				if ( !(supportflags & NETATOP || supportflags & NETATOPBPF) )
 				{
-					statmsg = "Kernel module 'netatop' not "
+					statmsg = "Module 'netatop' or 'netatop-bpf' not "
 					          "active or no root privs; "
 					          "request ignored!";
 					break;
@@ -1386,10 +1395,17 @@ text_samp(time_t curtime, int nsecs,
 				break;
 
 			   /*
-			   ** accumulated resource consumption per container
+			   ** accumulated resource consumption per container/pod
 			   */
 			   case MCUMCONT:
-				statmsg = "Consumption per container; use 'a' to "
+				if (!rawreadflag && !rootprivs())
+				{
+					statmsg = "No privileges to get "
+					          "container/pod identity!";
+					break;
+				}
+
+				statmsg = "Consumption per container/pod; use 'a' to "
 				          "toggle between all/active processes";
 
 				showtype  = MCUMCONT;
@@ -1627,57 +1643,41 @@ text_samp(time_t curtime, int nsecs,
 				break;
 
 			   /*
-			   ** focus on specific container id
+			   ** focus on specific container/pod id
 			   */
 			   case MSELCONT:
+				if (!rawreadflag && !rootprivs())
+				{
+					statmsg = "No privileges to get "
+					          "container/pod identity!";
+					beep();
+					break;
+				}
+
 				alarm(0);	/* stop the clock */
 				echo();
 
 				move(statline, 0);
 				clrtoeol();
-				printw("Containerid 12 postitions "
- 				       "(enter=all, "
+				printw("Container or pod name (enter=all, "
 				       "'host'=host processes): ");
 
-				procsel.container[0]  = '\0';
-				scanw("%15s", procsel.container);
-				procsel.container[12] = '\0';
+				procsel.utsname[0]  = '\0';
+				scanw("%15s", procsel.utsname);
+				procsel.utsname[UTSLEN] = '\0';
 
-				switch (strlen(procsel.container))
+				switch (strlen(procsel.utsname))
 				{
                                    case 0:
 					break;	// enter key pressed
 
 				   case 4:	// host?
-					if (strcmp(procsel.container, "host"))
+					if (strcmp(procsel.utsname, "host") == 0)
 					{
-						statmsg="Invalid containerid!";
-						beep();
-						procsel.container[0] = '\0';
-					}
-					else
-					{
-						procsel.container[0] = 'H';
-						procsel.container[1] = '\0';
+						procsel.utsname[0] = 'H';
+						procsel.utsname[1] = '\0';
 					}
 					break;
-
-				   case 12:	// container id
-					(void)strtol(procsel.container, &p, 16);
-
-					if (*p)
-					{
-						statmsg ="Containerid not hex!";
-						beep();
-						procsel.container[0] = '\0';
-					}
-					break;
-
-				   default:
-					statmsg = "Invalid containerid!";
-					beep();
-
-					procsel.container[0] = '\0';
 				}
 
 				noecho();
@@ -2095,6 +2095,13 @@ text_samp(time_t curtime, int nsecs,
 			   ** per-process PSS calculation wanted 
 			   */
 			   case MCALCPSS:
+				if (rawreadflag)
+				{
+					statmsg = "PSIZE gathering depends "
+					          "on rawfile";
+					break;
+				}
+
 				if (calcpss)
 				{
 					calcpss    = 0;
@@ -2103,7 +2110,12 @@ text_samp(time_t curtime, int nsecs,
 				else
 				{
 					calcpss    = 1;
-					statmsg    = "PSIZE gathering enabled";
+
+					if (rootprivs())
+						statmsg    = "PSIZE gathering enabled";
+					else
+						statmsg    = "PSIZE gathering only "
+						             "for own processes";
 				}
 				break;
 
@@ -2453,7 +2465,7 @@ cumprogs(struct tstat **curprocs, struct tstat *curprogs, int numprocs)
 }
 
 /*
-** accumulate all processes per container in new list
+** accumulate all processes per container/pod in new list
 */
 static int
 cumconts(struct tstat **curprocs, struct tstat *curconts, int numprocs)
@@ -2461,12 +2473,12 @@ cumconts(struct tstat **curprocs, struct tstat *curconts, int numprocs)
 	register int	i, numconts;
 
 	/*
-	** sort list of active processes in order of container (increasing)
+	** sort list of active processes in order of container/pod (increasing)
 	*/
 	qsort(curprocs, numprocs, sizeof(struct tstat *), compcon);
 
 	/*
-	** accumulate all processes per container in the new list
+	** accumulate all processes per container/pod in the new list
 	*/
 	for (numconts=i=0; i < numprocs; i++, curprocs++)
 	{
@@ -2476,16 +2488,16 @@ cumconts(struct tstat **curprocs, struct tstat *curconts, int numprocs)
 		if ((*curprocs)->gen.state == 'E' && suppressexit)
 			continue;
  
-		if ( strcmp(curconts->gen.container,
-                         (*curprocs)->gen.container) != 0)
+		if ( strcmp(curconts->gen.utsname,
+                         (*curprocs)->gen.utsname) != 0)
 		{
 			if (curconts->gen.pid)
 			{
 				numconts++;
 				curconts++;
 			}
-			strcpy(curconts->gen.container,
-			    (*curprocs)->gen.container);
+			strcpy(curconts->gen.utsname,
+			    (*curprocs)->gen.utsname);
 		}
 
 		accumulate(*curprocs, curconts);
@@ -2515,6 +2527,8 @@ accumulate(struct tstat *curproc, struct tstat *curstat)
 	curstat->cpu.stime  += curproc->cpu.stime;
 	curstat->cpu.nvcsw  += curproc->cpu.nvcsw;
 	curstat->cpu.nivcsw += curproc->cpu.nivcsw;
+	curstat->cpu.rundelay += curproc->cpu.rundelay;
+	curstat->cpu.blkdelay += curproc->cpu.blkdelay;
 
 	if (curproc->dsk.wsz > curproc->dsk.cwsz)
                	nett_wsz = curproc->dsk.wsz -curproc->dsk.cwsz;
@@ -2539,13 +2553,8 @@ accumulate(struct tstat *curproc, struct tstat *curstat)
 
 	if (curproc->gen.state != 'E')
 	{
-		if (curstat->mem.pmem != -1)
-		{
-			if  (curproc->mem.pmem != -1)  // no errors?
-				curstat->mem.pmem += curproc->mem.pmem;
-			else
-				curstat->mem.pmem  = -1;
-		}
+		if  (curproc->mem.pmem != -1)  // no errors?
+			curstat->mem.pmem += curproc->mem.pmem;
 
 		curstat->mem.vmem   += curproc->mem.vmem;
 		curstat->mem.rmem   += curproc->mem.rmem;
@@ -2661,19 +2670,19 @@ procsuppress(struct tstat *curstat, struct pselection *sel)
 	}
 
 	/*
-	** check if only processes related to a particular container
-	** should be shown (container 'H' stands for native host processes)
+	** check if only processes related to a particular container/pod
+	** should be shown (container/pod 'H' stands for native host processes)
 	*/
-	if (sel->container[0])
+	if (sel->utsname[0])
 	{
-		if (sel->container[0] == 'H')	// only host processes
+		if (sel->utsname[0] == 'H')	// only host processes
 		{
-			if (curstat->gen.container[0])
+			if (curstat->gen.utsname[0])
 				return 1;
 		}
 		else
 		{
-			if (memcmp(sel->container, curstat->gen.container, 12))
+			if (memcmp(sel->utsname, curstat->gen.utsname, 12))
 				return 1;
 		}
 	}
@@ -2854,9 +2863,14 @@ generic_init(void)
 		   case MPROCDSK:
 			if ( !(supportflags & IOSTAT) )
 			{
-				fprintf(stderr,
-					"No disk-activity figures "
-				        "available; request ignored\n");
+				if (rawreadflag)
+					fprintf(stderr,
+						"No disk activity in "
+						"raw file!\n");
+				else
+					fprintf(stderr,
+						"No privileges to view "
+						"disk activity!\n");
 				sleep(3);
 				break;
 			}
@@ -2866,10 +2880,10 @@ generic_init(void)
 			break;
 
 		   case MPROCNET:
-			if ( !(supportflags & NETATOP) )
+			if ( !(supportflags & NETATOP || supportflags & NETATOPBPF) )
 			{
-				fprintf(stderr, "Kernel module 'netatop' not "
-					          "active; request ignored!\n");
+				fprintf(stderr, "Module 'netatop' or 'netatop-bpf' not "
+					          "active; request ignored!");
 				sleep(3);
 				break;
 			}
@@ -2918,6 +2932,14 @@ generic_init(void)
 			break;
 
 		   case MCUMCONT:
+			if (!rawreadflag && !rootprivs())
+			{
+				fprintf(stderr, "No privileges to get "
+				                "container/pod identity!\n");
+				sleep(3);
+				break;
+			}
+
 			showtype  = MCUMCONT;
 			break;
 
@@ -2950,10 +2972,29 @@ generic_init(void)
 			break;
 
 		   case MCALCPSS:
+			if (rawreadflag)
+			{
+				fprintf(stderr,
+				        "PSIZE gathering depends on rawfile\n");
+				sleep(3);
+				break;
+			}
 			if (calcpss)
-				calcpss = 0;
+			{
+				calcpss    = 0;
+			}
 			else
-				calcpss = 1;
+			{
+				calcpss    = 1;
+
+				if (!rootprivs())
+				{
+					fprintf(stderr,
+				 	        "PSIZE gathering only for own "
+					        "processes\n");
+					sleep(3);
+				}
+			}
 			break;
 
 		   case MGETWCHAN:
@@ -3145,14 +3186,14 @@ static struct helptext {
 	{"\t'%c'  - total resource consumption per user\n", 	MCUMUSER},
 	{"\t'%c'  - total resource consumption per program (i.e. same "
 	 "process name)\n",					MCUMPROC},
-	{"\t'%c'  - total resource consumption per container\n",MCUMCONT},
+	{"\t'%c'  - total resource consumption per container/pod\n",MCUMCONT},
 	{"\n",							' '},
 	{"Process selections (keys shown in header line):\n",	' '},
 	{"\t'%c'  - focus on specific user name           "
 	                              "(regular expression)\n", MSELUSER},
 	{"\t'%c'  - focus on specific program name        "
 	                              "(regular expression)\n", MSELPROC},
-	{"\t'%c'  - focus on specific container id (CID)\n",    MSELCONT},
+	{"\t'%c'  - focus on specific container/pod name\n",    MSELCONT},
 	{"\t'%c'  - focus on specific command line string "
 	                              "(regular expression)\n", MSELARG},
 	{"\t'%c'  - focus on specific process id (PID)\n",      MSELPID},
@@ -3361,7 +3402,7 @@ generic_usage(void)
 	printf("\t  -%c  show cumulated process-info per program "
 	                "(i.e. same name)\n",
 			MCUMPROC);
-	printf("\t  -%c  show cumulated process-info per container\n\n",
+	printf("\t  -%c  show cumulated process-info per container/pod\n\n",
 			MCUMCONT);
 	printf("\t  -%c  sort processes in order of cpu consumption "
 	                "(default)\n",
