@@ -44,6 +44,7 @@ typedef struct {
         int		ntrun;
         int		ntslpi;
         int		ntslpu;
+        int		ntidle;
         int		nzomb;
         int		nexit;
         int		noverflow;
@@ -175,6 +176,7 @@ extern sys_printdef syspdef_PRCNPROC;
 extern sys_printdef syspdef_PRCNRUNNING;
 extern sys_printdef syspdef_PRCNSLEEPING;
 extern sys_printdef syspdef_PRCNDSLEEPING;
+extern sys_printdef syspdef_PRCNIDLE;
 extern sys_printdef syspdef_PRCNZOMBIE;
 extern sys_printdef syspdef_PRCCLONES;
 extern sys_printdef syspdef_PRCNNEXIT;
@@ -218,6 +220,7 @@ extern sys_printdef syspdef_GPUMEMUSE;
 extern sys_printdef syspdef_GPUMEMAVG;
 extern sys_printdef syspdef_MEMTOT;
 extern sys_printdef syspdef_MEMFREE;
+extern sys_printdef syspdef_MEMAVAIL;
 extern sys_printdef syspdef_MEMCACHE;
 extern sys_printdef syspdef_MEMDIRTY;
 extern sys_printdef syspdef_MEMBUFFER;
@@ -229,12 +232,13 @@ extern sys_printdef syspdef_SHMSWP;
 extern sys_printdef syspdef_VMWBAL;
 extern sys_printdef syspdef_ZFSARC;
 extern sys_printdef syspdef_PAGETABS;
+extern sys_printdef syspdef_ANONTHP;
 extern sys_printdef syspdef_HUPTOT;
 extern sys_printdef syspdef_HUPUSE;
 extern sys_printdef syspdef_SWPTOT;
 extern sys_printdef syspdef_SWPFREE;
 extern sys_printdef syspdef_SWPCACHE;
-extern sys_printdef syspdef_ZSWTOTAL;
+extern sys_printdef syspdef_ZSWPOOL;
 extern sys_printdef syspdef_ZSWSTORED;
 extern sys_printdef syspdef_KSMSHARING;
 extern sys_printdef syspdef_KSMSHARED;
@@ -253,6 +257,7 @@ extern sys_printdef syspdef_NUMASHMEM;
 extern sys_printdef syspdef_NUMASLABRECLAIM;
 extern sys_printdef syspdef_NUMAFRAG;
 extern sys_printdef syspdef_NUMAHUPTOT;
+extern sys_printdef syspdef_NUMAHUPUSE;
 extern sys_printdef syspdef_NUMANUMCPU;
 extern sys_printdef syspdef_NUMACPUSYS;
 extern sys_printdef syspdef_NUMACPUUSER;
@@ -278,6 +283,8 @@ extern sys_printdef syspdef_TCPSOCK;
 extern sys_printdef syspdef_UDPSOCK;
 extern sys_printdef syspdef_PAGSWIN;
 extern sys_printdef syspdef_PAGSWOUT;
+extern sys_printdef syspdef_PAGZSWIN;
+extern sys_printdef syspdef_PAGZSWOUT;
 extern sys_printdef syspdef_OOMKILLS;
 extern sys_printdef syspdef_PSICPUSTOT;
 extern sys_printdef syspdef_PSIMEMSTOT;
@@ -314,6 +321,7 @@ extern sys_printdef syspdef_NETTCPPASVOPEN;
 extern sys_printdef syspdef_NETTCPRETRANS;
 extern sys_printdef syspdef_NETTCPINERR;
 extern sys_printdef syspdef_NETTCPORESET;
+extern sys_printdef syspdef_NETTCPCSUMERR;
 extern sys_printdef syspdef_NETUDPNOPORT;
 extern sys_printdef syspdef_NETUDPINERR;
 extern sys_printdef syspdef_NETUDPI;
@@ -422,6 +430,7 @@ extern proc_printdef procprt_THR;
 extern proc_printdef procprt_TRUN;
 extern proc_printdef procprt_TSLPI;
 extern proc_printdef procprt_TSLPU;
+extern proc_printdef procprt_TIDLE;
 extern proc_printdef procprt_POLI;
 extern proc_printdef procprt_NICE;
 extern proc_printdef procprt_PRI;
