@@ -123,6 +123,8 @@ char *procprt_TSLPI_a(struct tstat *, int, int);
 char *procprt_TSLPI_e(struct tstat *, int, int);
 char *procprt_TSLPU_a(struct tstat *, int, int);
 char *procprt_TSLPU_e(struct tstat *, int, int);
+char *procprt_TIDLE_a(struct tstat *, int, int);
+char *procprt_TIDLE_e(struct tstat *, int, int);
 char *procprt_POLI_a(struct tstat *, int, int);
 char *procprt_POLI_e(struct tstat *, int, int);
 char *procprt_NICE_a(struct tstat *, int, int);
@@ -652,10 +654,10 @@ procprt_CID_a(struct tstat *curstat, int avgval, int nsecs)
 {
         static char buf[64];
 
-	if (curstat->gen.container[0])
-        	sprintf(buf, "%-12s", curstat->gen.container);
+	if (curstat->gen.utsname[0])
+        	sprintf(buf, "%-15s", curstat->gen.utsname);
 	else
-        	sprintf(buf, "%-12s", "host--------");
+        	sprintf(buf, "%-15s", "host-----------");
 
         return buf;
 }
@@ -665,16 +667,16 @@ procprt_CID_e(struct tstat *curstat, int avgval, int nsecs)
 {
         static char buf[64];
 
-	if (curstat->gen.container[0])
-        	sprintf(buf, "%-12s", curstat->gen.container);
+	if (curstat->gen.utsname[0])
+        	sprintf(buf, "%-15s", curstat->gen.utsname);
 	else
-        	sprintf(buf, "%-12s", "?");
+        	sprintf(buf, "%-15s", "?");
 
         return buf;
 }
 
 proc_printdef procprt_CID = 
-   { "CID         ", "CID", procprt_CID_a, procprt_CID_e, 12};
+   { "CID/POD        ", "CID", procprt_CID_a, procprt_CID_e, 15};
 /***************************************************************/
 char *
 procprt_SYSCPU_ae(struct tstat *curstat, int avgval, int nsecs)
@@ -1306,6 +1308,24 @@ procprt_TSLPU_e(struct tstat *curstat, int avgval, int nsecs)
 proc_printdef procprt_TSLPU = 
    { "TSLPU", "TSLPU", procprt_TSLPU_a, procprt_TSLPU_e, 5 };
 /***************************************************************/
+char *
+procprt_TIDLE_a(struct tstat *curstat, int avgval, int nsecs)
+{
+        static char buf[15];
+
+        sprintf(buf, "%5d", curstat->gen.nthridle);
+        return buf;
+}
+
+char *
+procprt_TIDLE_e(struct tstat *curstat, int avgval, int nsecs)
+{
+        return "    0";
+}
+
+proc_printdef procprt_TIDLE = 
+   { "TIDLE", "TIDLE", procprt_TIDLE_a, procprt_TIDLE_e, 5 };
+/***************************************************************/
 #define SCHED_NORMAL	0
 #define SCHED_FIFO	1
 #define SCHED_RR	2
@@ -1641,7 +1661,7 @@ procprt_TCPRCV_a(struct tstat *curstat, int avgval, int nsecs)
 char *
 procprt_TCPRCV_e(struct tstat *curstat, int avgval, int nsecs) 
 {      
-	if (supportflags & NETATOPD)
+	if (supportflags & NETATOPD || supportflags & NETATOPBPF )
 	{
         	static char buf[10];
         
@@ -1672,7 +1692,7 @@ procprt_TCPRASZ_a(struct tstat *curstat, int avgval, int nsecs)
 char *
 procprt_TCPRASZ_e(struct tstat *curstat, int avgval, int nsecs)
 {
-	if (supportflags & NETATOPD)
+	if (supportflags & NETATOPD || supportflags & NETATOPBPF )
 	{
         	static char buf[10];
         
@@ -1702,7 +1722,7 @@ procprt_TCPSND_a(struct tstat *curstat, int avgval, int nsecs)
 char *
 procprt_TCPSND_e(struct tstat *curstat, int avgval, int nsecs)
 {
-	if (supportflags & NETATOPD)
+	if (supportflags & NETATOPD || supportflags & NETATOPBPF )
 	{
         	static char buf[10];
         
@@ -1732,7 +1752,7 @@ procprt_TCPSASZ_a(struct tstat *curstat, int avgval, int nsecs)
 char *
 procprt_TCPSASZ_e(struct tstat *curstat, int avgval, int nsecs)
 {
-	if (supportflags & NETATOPD)
+	if (supportflags & NETATOPD || supportflags & NETATOPBPF )
 	{
         	static char buf[10];
         
@@ -1762,7 +1782,7 @@ procprt_UDPRCV_a(struct tstat *curstat, int avgval, int nsecs)
 char *
 procprt_UDPRCV_e(struct tstat *curstat, int avgval, int nsecs) 
 {
-	if (supportflags & NETATOPD)
+	if (supportflags & NETATOPD || supportflags & NETATOPBPF )
 	{
         	static char buf[10];
         
@@ -1793,7 +1813,7 @@ procprt_UDPRASZ_a(struct tstat *curstat, int avgval, int nsecs)
 char *
 procprt_UDPRASZ_e(struct tstat *curstat, int avgval, int nsecs)
 {
-	if (supportflags & NETATOPD)
+	if (supportflags & NETATOPD || supportflags & NETATOPBPF )
 	{
         	static char buf[10];
         
@@ -1824,7 +1844,7 @@ procprt_UDPSND_a(struct tstat *curstat, int avgval, int nsecs)
 char *
 procprt_UDPSND_e(struct tstat *curstat, int avgval, int nsecs)
 {
-	if (supportflags & NETATOPD)
+	if (supportflags & NETATOPD || supportflags & NETATOPBPF )
 	{
         	static char buf[10];
         
@@ -1854,7 +1874,7 @@ procprt_UDPSASZ_a(struct tstat *curstat, int avgval, int nsecs)
 char *
 procprt_UDPSASZ_e(struct tstat *curstat, int avgval, int nsecs)
 {
-	if (supportflags & NETATOPD)
+	if (supportflags & NETATOPD || supportflags & NETATOPBPF )
 	{
         	static char buf[10];
         
@@ -1886,7 +1906,7 @@ procprt_RNET_a(struct tstat *curstat, int avgval, int nsecs)
 char *
 procprt_RNET_e(struct tstat *curstat, int avgval, int nsecs)
 {
-	if (supportflags & NETATOPD)
+	if (supportflags & NETATOPD || supportflags & NETATOPBPF )
 	{
         	static char buf[10];
  
@@ -1915,7 +1935,7 @@ procprt_SNET_a(struct tstat *curstat, int avgval, int nsecs)
 char *
 procprt_SNET_e(struct tstat *curstat, int avgval, int nsecs)
 {
-	if (supportflags & NETATOPD)
+	if (supportflags & NETATOPD || supportflags & NETATOPBPF )
 	{
 	        static char buf[10];
         
@@ -1943,7 +1963,7 @@ procprt_BANDWI_a(struct tstat *curstat, int avgval, int nsecs)
 char *
 procprt_BANDWI_e(struct tstat *curstat, int avgval, int nsecs)
 {
-	if (supportflags & NETATOPD)
+	if (supportflags & NETATOPD || supportflags & NETATOPBPF )
 	{
         	static char buf[16];
 		count_t     rkbps = (curstat->net.tcprsz + curstat->net.udprsz)
@@ -1972,7 +1992,7 @@ procprt_BANDWO_a(struct tstat *curstat, int avgval, int nsecs)
 char *
 procprt_BANDWO_e(struct tstat *curstat, int avgval, int nsecs)
 {
-	if (supportflags & NETATOPD)
+	if (supportflags & NETATOPD || supportflags & NETATOPBPF )
 	{
         	static char buf[16];
 		count_t     skbps = (curstat->net.tcpssz + curstat->net.udpssz)
