@@ -38,18 +38,19 @@
 #include <time.h>
 #include <math.h>
 #include <stdio.h>
-#include <unistd.h>
 #include <ctype.h>
 #include <stdlib.h>
 #include <errno.h>
 #include <stdarg.h>
 #include <string.h>
 #include <fcntl.h>
-#include <wait.h>
+#include <sys/wait.h>
+#include <unistd.h>
 
 #include "atop.h"
 #include "acctproc.h"
 
+int getresuid(uid_t *ruid, uid_t *euid, uid_t *suid);
 
 static unsigned long long getbootlinux(long);
 
@@ -90,11 +91,11 @@ convdate(time_t utime, char *chardat)
 
 
 /*
-** Convert a string in format [YYYYMMDD]hh[:]mm into an epoch time value or
+** Convert a string in format [YYYYMMDD]hh[:]mm[:][ss] into an epoch time value or
 ** when only the value hh[:]mm was given, take this time from midnight.
 **
-** Arguments:		String with date-time in format [YYYYMMDD]hh[:]mm
-** 			or hh[:]mm.
+** Arguments:		String with date-time in format [YYYYMMDD]hh[:]mm[:][ss]
+** 			or hh[:]mm[:][ss].
 **
 **			Pointer to time_t containing 0 or current epoch time.
 **
@@ -105,7 +106,7 @@ int
 getbranchtime(char *itim, time_t *newtime)
 {
 	register int	ilen = strlen(itim);
-	int		hours, minutes;
+	int		hours, minutes, seconds;
 	time_t		epoch;
 	struct tm	tm;
 
@@ -114,8 +115,42 @@ getbranchtime(char *itim, time_t *newtime)
 	/*
 	** verify length of input string
 	*/
-	if (ilen != 4 && ilen != 5 && ilen != 12 && ilen != 13)
-		return 0;		// wrong date-time format
+	if (ilen != 4 && ilen != 5 &&   // hhmm or hh:mm
+	    ilen != 6 && ilen != 8 &&   // hhmmss or hh:mm:ss
+	    ilen != 12 && ilen != 13 && // YYYYMMDDhhmm or YYYYMMDDhh:mm
+	    ilen != 14 && ilen != 16)   // YYYYMMDDhhmmss or YYYYMMDDhh:mm:ss
+	        return 0;               // wrong date-time format
+
+	/*
+	** check string syntax for absolute time specified as
+	** YYYYMMDDhh:mm:ss or YYYYMMDDhhmmss
+	*/
+	if ( sscanf(itim, "%4d%2d%2d%2d:%2d:%2d", &tm.tm_year, &tm.tm_mon,
+	                        &tm.tm_mday,  &tm.tm_hour, &tm.tm_min, &tm.tm_sec) == 6 ||
+	     sscanf(itim, "%4d%2d%2d%2d%2d%2d",  &tm.tm_year, &tm.tm_mon,
+	                        &tm.tm_mday,  &tm.tm_hour, &tm.tm_min, &tm.tm_sec) == 6   )
+	{
+	        tm.tm_year -= 1900;
+	        tm.tm_mon  -= 1;
+
+	        if (tm.tm_year < 100 || tm.tm_mon  < 0  || tm.tm_mon > 11 ||
+	            tm.tm_mday < 1   || tm.tm_mday > 31 ||
+	            tm.tm_hour < 0   || tm.tm_hour > 23 ||
+	            tm.tm_min  < 0   || tm.tm_min  > 59 ||
+	            tm.tm_sec  < 0   || tm.tm_sec  > 59   )
+	        {
+	                return 0;       // wrong date-time format
+	        }
+
+	        tm.tm_isdst = -1;
+
+	        if ((epoch = mktime(&tm)) == -1)
+	                return 0;       // wrong date-time format
+
+	        // correct date-time format
+	        *newtime = epoch;
+	        return 1;
+	}
 
 	/*
 	** check string syntax for absolute time specified as
@@ -147,6 +182,42 @@ getbranchtime(char *itim, time_t *newtime)
 		return 1;
 	}
 
+	/*
+	** check string syntax for relative time specified as
+	** hh:mm:ss or hhmmss
+	*/
+	if ( sscanf(itim, "%2d:%2d:%2d", &hours, &minutes, &seconds) == 3 ||
+	     sscanf(itim, "%2d%2d%2d",  &hours, &minutes, &seconds) == 3 )
+	{
+	        if ( hours < 0 || hours > 23 ||
+	             minutes < 0 || minutes > 59 ||
+	             seconds < 0 || seconds > 59 )
+	                return 0;       // wrong date-time format
+
+	        /*
+	        ** when the new time is already filled with an epoch time,
+	        ** the relative time will be on the same day as indicated by
+	        ** that epoch time
+	        ** when the new time is the time within a day or 0, the new
+	        ** time will be stored again as the time within a day.
+	        */
+	        if (*newtime <= SECONDSINDAY)   // time within the day?
+	        {
+	                *newtime = (hours * 3600) + (minutes * 60) + seconds;
+
+	                if (*newtime >= SECONDSINDAY)
+	                        *newtime = SECONDSINDAY-1;
+
+	                return 1;
+	        }
+	        else
+	        {
+	                *newtime = normalize_epoch(*newtime,
+	                                        (hours*3600) + (minutes*60) + seconds);
+	                return 1;
+	        }
+	}
+
 	/*
 	** check string syntax for relative time specified as
 	** hh:mm or hhmm
@@ -774,6 +845,20 @@ cleanstop(int exitcode)
 	exit(exitcode);
 }
 
+/*
+** determine if we are running with root privileges
+** returns: boolean
+*/
+int
+rootprivs(void)
+{
+        uid_t ruid, euid, suid;
+
+        getresuid(&ruid, &euid, &suid);
+
+        return !suid;
+}
+
 /*
 ** drop the root privileges that might be obtained via setuid-bit
 **
@@ -814,7 +899,7 @@ void
 set_oom_score_adj(void)
 {
 	int fd;
-	char val[] = "-1000";	/* suggested by Gerlof, always set -1000 */
+	char val[] = "-999";	/* suggested by Gerlof, always set -999 */
 
 	/*
 	 ** set OOM score adj to avoid to lost necessary log of system.
